@@ -6,9 +6,9 @@ import os
 
 def execute_script():
     dataframe1 = pd.read_csv(os.path.join("..", "tests", "input_data", "interleavings", "receipt_even.csv"))
-    dataframe1 = pm4py.format_dataframe(dataframe1)
+    dataframe1["time:timestamp"] = pd.to_datetime(dataframe1["time:timestamp"], utc=True)
     dataframe2 = pd.read_csv(os.path.join("..", "tests", "input_data", "interleavings", "receipt_odd.csv"))
-    dataframe2 = pm4py.format_dataframe(dataframe2)
+    dataframe2["time:timestamp"] = pd.to_datetime(dataframe2["time:timestamp"], utc=True)
     case_relations = pd.read_csv(os.path.join("..", "tests", "input_data", "interleavings", "case_relations.csv"))
     merged = case_relations_merging.apply(dataframe1, dataframe2, case_relations)
     dfg, sa, ea = pm4py.discover_dfg(merged)
