@@ -23,7 +23,10 @@ from pm4py.statistics.variants.log.get import get_variants, \
 from pm4py.util import exec_utils
 from pm4py.util.constants import PARAMETER_CONSTANT_ACTIVITY_KEY
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
-import deprecation
+
+from typing import Optional, Dict, Any, Union, Tuple, List
+from pm4py.objects.log.obj import EventLog, EventStream, Trace
+from pm4py.objects.conversion.log import converter as log_converter
 
 
 class Parameters(Enum):
@@ -32,7 +35,7 @@ class Parameters(Enum):
     POSITIVE = "positive"
 
 
-def apply(log, admitted_variants, parameters=None):
+def apply(log: EventLog, admitted_variants: List[List[str]], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Filter log keeping/removing only provided variants
 
@@ -50,6 +53,9 @@ def apply(log, admitted_variants, parameters=None):
 
     if parameters is None:
         parameters = {}
+
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
     variants = get_variants(log, parameters=parameters)
     log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
@@ -82,6 +88,8 @@ def filter_variants_top_k(log, k, parameters=None):
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     variants = get_variants(log, parameters=parameters)
     variant_count = get_variants_sorted_by_count(variants)
     variant_count = variant_count[:min(k, len(variant_count))]
@@ -114,6 +122,8 @@ def filter_variants_by_coverage_percentage(log, min_coverage_percentage, paramet
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     variants = get_variants(log, parameters=parameters)
     variants = {x: len(y) for x, y in variants.items()}
     allowed_variants = [x for x, y in variants.items() if y >= min_coverage_percentage * len(log)]
@@ -142,6 +152,8 @@ def filter_log_variants_percentage(log, percentage=0.8, parameters=None):
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     variants = get_variants(log, parameters=parameters)
 
     return filter_variants_variants_percentage(log, variants, variants_percentage=percentage)
@@ -165,6 +177,8 @@ def filter_variants_variants_percentage(log, variants, variants_percentage=0.0):
     filtered_log
         Filtered log
     """
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG)
+
     filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
                             omni_present=log.omni_present, properties=log.properties)
     no_of_traces = len(log)
@@ -225,40 +239,3 @@ def find_auto_threshold(log, variants, decreasing_factor):
     percentage_already_added = already_added_sum / no_of_traces
 
     return percentage_already_added
-
-
-@deprecation.deprecated("2.2.11", "3.0.0", details="Removed")
-def apply_auto_filter(log, variants=None, parameters=None):
-    """
-    Apply a variants filter detecting automatically a percentage
-    
-    Parameters
-    ----------
-    log
-        Log
-    variants
-        Variants contained in the log
-    parameters
-        Parameters of the algorithm, including:
-            Parameters.ACTIVITY_KEY -> Key that identifies the activity
-            Parameters.DECREASING_FACTOR -> Decreasing factor (stops the algorithm when the next variant by occurrence is below
-            this factor in comparison to previous)
-    
-    Returns
-    ----------
-    filteredLog
-        Filtered log
-    """
-    if parameters is None:
-        parameters = {}
-
-    attribute_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, DEFAULT_NAME_KEY)
-    decreasing_factor = exec_utils.get_param_value(Parameters.DECREASING_FACTOR, parameters,
-                                                   filtering_constants.DECREASING_FACTOR)
-
-    parameters_variants = {PARAMETER_CONSTANT_ACTIVITY_KEY: attribute_key}
-    if variants is None:
-        variants = get_variants(log, parameters=parameters_variants)
-    variants_percentage = find_auto_threshold(log, variants, decreasing_factor)
-    filtered_log = filter_variants_variants_percentage(log, variants, variants_percentage)
-    return filtered_log
