@@ -14,23 +14,25 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from typing import List, Any, Dict
+from typing import List, Dict
 from enum import Enum
 from pm4py.util import exec_utils
+from pm4py.objects.org.sna.obj import SNA
+import numpy as np
 
 
 class Parameters(Enum):
     WEIGHT_THRESHOLD = "weight_threshold"
 
 
-def sna_result_to_nx_graph(sna_results: List[List[Any]], parameters=None):
+def sna_result_to_nx_graph(sna: SNA, parameters=None):
     """
     Transforms the results of SNA to a NetworkX Graph / DiGraph object
     (depending on the type of analysis).
 
     Parameters
     ------------------
-    sna_results
+    sna
         Result of a SNA operation
     parameters
         Parameters of the algorithm, including:
@@ -45,39 +47,28 @@ def sna_result_to_nx_graph(sna_results: List[List[Any]], parameters=None):
         parameters = {}
 
     import networkx as nx
-    import numpy as np
 
     weight_threshold = exec_utils.get_param_value(Parameters.WEIGHT_THRESHOLD, parameters, 0.0)
-    directed = sna_results[2]
+    directed = sna.is_directed
 
-    rows, cols = np.where(sna_results[0] > weight_threshold)
-    edges = zip(rows.tolist(), cols.tolist())
     if directed:
         graph = nx.DiGraph()
     else:
         graph = nx.Graph()
-    labels = {}
-    nodes = []
-    for index, item in enumerate(sna_results[1]):
-        labels[index] = item
-        nodes.append(item)
 
-    edges = [(labels[e[0]], labels[e[1]]) for e in edges]
-
-    graph.add_nodes_from(nodes)
-    graph.add_edges_from(edges)
+    graph.add_edges_from({c for c, w in sna.connections.items() if w >= weight_threshold})
 
     return graph
 
 
-def cluster_affinity_propagation(sna_results: List[List[Any]], parameters=None) -> Dict[str, List[str]]:
+def cluster_affinity_propagation(sna: SNA, parameters=None) -> Dict[str, List[str]]:
     """
     Performs a clustering using the affinity propagation algorithm provided by Scikit Learn
 
     Parameters
     --------------
-    sna_results
-        Values for a SNA metric
+    sna
+        Result of a SNA operation
     parameters
         Parameters of the algorithm
 
@@ -92,8 +83,11 @@ def cluster_affinity_propagation(sna_results: List[List[Any]], parameters=None)
     if parameters is None:
         parameters = {}
 
-    matrix = sna_results[0]
-    originators = sna_results[1]
+    originators = list(set(x[0] for x, y in sna.connections.items()).union(set(x[1] for x, y in sna.connections.items())))
+    matrix = np.zeros((len(originators), len(originators)))
+    for c, w in sna.connections.items():
+        matrix[originators.index(c[0]), originators.index(c[1])] = w
+
     affinity_propagation = AffinityPropagation(**parameters)
     affinity_propagation.fit(matrix)
 
