@@ -15,9 +15,9 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 __name__ = 'pm4py'
-VERSION = '2.2.32'
+VERSION = '2.3.0'
 __version__ = VERSION
-__doc__ = 'Process Mining for Python (PM4Py)'
+__doc__ = 'Process mining for Python'
 __author__ = 'Fraunhofer Institute for Applied Technology'
 __author_email__ = 'pm4py@fit.fraunhofer.de'
 __maintainer__ = 'Fraunhofer Institute for Applied Technology'
