@@ -15,7 +15,6 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 import copy
-import deprecation
 from pm4py.objects.petri_net.sem_interface import Semantics
 
 
@@ -114,14 +113,6 @@ def execute(t, pn, m):
     return m_out
 
 
-@deprecation.deprecated("2.2.13", "3.0.0", details="please use the execute method.")
-def try_to_execute(t, pn, m):
-    if not is_enabled(t, pn, m):
-        return None
-    else:
-        return execute(t, pn, m)
-
-
 def weak_execute(t, m):
     m_out = copy.copy(m)
     for a in t.in_arcs:
