@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.visualization.footprints import variants, visualizer
+
+import warnings
+
+warnings.warn("The footprints visualizer will be removed in a future release.")
