@@ -2,6 +2,7 @@ from pm4py.objects.log.util import dataframe_utils
 import unittest
 import os
 import pandas as pd
+from pm4py.objects.conversion.process_tree import converter as process_tree_converter
 
 
 class DocTests(unittest.TestCase):
@@ -75,7 +76,7 @@ class DocTests(unittest.TestCase):
         from pm4py.objects.conversion.log import converter as log_converter
 
         log_csv = pd.read_csv(os.path.join("input_data", "running-example.csv"), sep=',')
-        event_log = log_converter.apply(log_csv)
+        event_log = log_converter.apply(log_csv, variant=log_converter.Variants.TO_EVENT_LOG)
 
     def test_4(self):
         import pandas as pd
@@ -335,12 +336,13 @@ class DocTests(unittest.TestCase):
         from pm4py.algo.discovery.inductive import algorithm as inductive_miner
 
         log = xes_importer.apply(os.path.join("input_data", "running-example.xes"))
-        net, initial_marking, final_marking = inductive_miner.apply(log)
+        process_tree = inductive_miner.apply(log)
+        net, initial_marking, final_marking = process_tree_converter.apply(process_tree)
 
         from pm4py.algo.discovery.inductive import algorithm as inductive_miner
         from pm4py.visualization.process_tree import visualizer as pt_visualizer
 
-        tree = inductive_miner.apply_tree(log)
+        tree = inductive_miner.apply(log)
 
         gviz = pt_visualizer.apply(tree)
 
@@ -420,7 +422,8 @@ class DocTests(unittest.TestCase):
 
         import os
         from pm4py.algo.discovery.inductive import algorithm as inductive_miner
-        net, initial_marking, final_marking = inductive_miner.apply(log)
+        process_tree = inductive_miner.apply(log)
+        net, initial_marking, final_marking = process_tree_converter.apply(process_tree)
 
         from pm4py.visualization.petri_net import visualizer as pn_visualizer
         parameters = {pn_visualizer.Variants.WO_DECORATION.value.Parameters.FORMAT: "png"}
@@ -553,7 +556,8 @@ class DocTests(unittest.TestCase):
 
         log = xes_importer.apply(os.path.join("input_data", "running-example.xes"))
 
-        net, initial_marking, final_marking = inductive_miner.apply(log)
+        process_tree = inductive_miner.apply(log)
+        net, initial_marking, final_marking = process_tree_converter.apply(process_tree)
 
         from pm4py.algo.conformance.alignments.petri_net import algorithm as alignments
         alignments = alignments.apply_log(log, net, initial_marking, final_marking)
@@ -571,11 +575,12 @@ class DocTests(unittest.TestCase):
         from pm4py.algo.conformance.alignments.petri_net import algorithm as alignments
 
         # define the activity key in the parameters
-        parameters = {inductive_miner.Variants.IM_CLEAN.value.Parameters.ACTIVITY_KEY: "customClassifier",
+        parameters = {inductive_miner.Parameters.ACTIVITY_KEY: "customClassifier",
                       alignments.Variants.VERSION_STATE_EQUATION_A_STAR.value.Parameters.ACTIVITY_KEY: "customClassifier"}
 
         # calculate process model using the given classifier
-        net, initial_marking, final_marking = inductive_miner.apply(log, parameters=parameters)
+        process_tree = inductive_miner.apply(log)
+        net, initial_marking, final_marking = process_tree_converter.apply(process_tree)
         alignments = alignments.apply_log(log, net, initial_marking, final_marking, parameters=parameters)
 
         from pm4py.algo.evaluation.replay_fitness import algorithm as replay_fitness
@@ -588,7 +593,8 @@ class DocTests(unittest.TestCase):
 
         log = xes_importer.apply(os.path.join("input_data", "running-example.xes"))
 
-        net, initial_marking, final_marking = inductive_miner.apply(log)
+        process_tree = inductive_miner.apply(log)
+        net, initial_marking, final_marking = process_tree_converter.apply(process_tree)
 
         from pm4py.algo.conformance.alignments.petri_net import algorithm as alignments
 
@@ -721,7 +727,8 @@ class DocTests(unittest.TestCase):
         filtered_log = variants_filter.filter_log_variants_percentage(log, 0.2)
 
         from pm4py.algo.discovery.inductive import algorithm as inductive_miner
-        net, initial_marking, final_marking = inductive_miner.apply(filtered_log)
+        process_tree = inductive_miner.apply(log)
+        net, initial_marking, final_marking = process_tree_converter.apply(process_tree)
 
         from pm4py.algo.conformance.tokenreplay import algorithm as token_based_replay
         parameters_tbr = {token_based_replay.Variants.TOKEN_REPLAY.value.Parameters.DISABLE_VARIANTS: True,
@@ -752,7 +759,8 @@ class DocTests(unittest.TestCase):
         filtered_log = variants_filter.filter_log_variants_percentage(log, 0.2)
 
         from pm4py.algo.discovery.inductive import algorithm as inductive_miner
-        net, initial_marking, final_marking = inductive_miner.apply(filtered_log)
+        process_tree = inductive_miner.apply(log)
+        net, initial_marking, final_marking = process_tree_converter.apply(process_tree)
 
         # build decision trees
         string_attributes = ["org:group"]
@@ -853,7 +861,8 @@ class DocTests(unittest.TestCase):
         log = xes_importer.apply(os.path.join("input_data", "running-example.xes"))
 
         from pm4py.algo.discovery.inductive import algorithm as inductive_miner
-        net, im, fm = inductive_miner.apply(log)
+        process_tree = inductive_miner.apply(log)
+        net, im, fm = process_tree_converter.apply(process_tree)
 
         from pm4py.algo.discovery.footprints import algorithm as footprints_discovery
 
@@ -883,7 +892,8 @@ class DocTests(unittest.TestCase):
         filtered_log = variants_filter.filter_log_variants_percentage(log, 0.2)
 
         from pm4py.algo.discovery.inductive import algorithm as inductive_miner
-        net, im, fm = inductive_miner.apply(filtered_log)
+        process_tree = inductive_miner.apply(log)
+        net, im, fm = process_tree_converter.apply(process_tree)
 
         from pm4py.algo.conformance.footprints import algorithm as footprints_conformance
 
@@ -955,14 +965,15 @@ class DocTests(unittest.TestCase):
     def test_business_hours(self):
         from pm4py.util.business_hours import BusinessHours
         from datetime import datetime
+        from pm4py.util import constants
 
         st = datetime.fromtimestamp(100000000)
         et = datetime.fromtimestamp(200000000)
         bh_object = BusinessHours(st, et)
-        worked_time = bh_object.getseconds()
+        worked_time = bh_object.get_seconds()
 
-        bh_object = BusinessHours(st, et, worktiming=[10, 16], weekends=[5, 6, 7])
-        worked_time = bh_object.getseconds()
+        bh_object = BusinessHours(st, et, business_hour_slots=constants.DEFAULT_BUSINESS_HOUR_SLOTS)
+        worked_time = bh_object.get_seconds()
 
     def test_cycle_waiting_time(self):
         from pm4py.objects.log.importer.xes import importer as xes_importer
