@@ -5,6 +5,7 @@ from pm4py.algo.discovery.inductive import algorithm as inductive_miner
 from pm4py.algo.evaluation.precision import algorithm as etc_alg
 from pm4py.objects.log.importer.xes import importer as xes_importer
 from tests.constants import INPUT_DATA_DIR
+from pm4py.objects.conversion.process_tree import converter as process_tree_converter
 
 
 class ETCTest(unittest.TestCase):
@@ -13,7 +14,8 @@ class ETCTest(unittest.TestCase):
         # that by construction of the unittest package have to be expressed in such way
         self.dummy_variable = "dummy_value"
         log = xes_importer.apply(os.path.join(INPUT_DATA_DIR, "running-example.xes"))
-        net, marking, final_marking = inductive_miner.apply(log)
+        process_tree = inductive_miner.apply(log)
+        net, marking, final_marking = process_tree_converter.apply(process_tree)
         precision = etc_alg.apply(log, net, marking, final_marking, variant=etc_alg.ETCONFORMANCE_TOKEN)
         del precision
 
